Attribute VB_Name = "ListviewColResize"
' Modul         : ListviewColResize
' System        : VB 6.0 SP6
' Copyright (C) : E+A Forschungsinstitut Elektromaschinen GmbH, CH-4313 Mhlin
'
' Beschreibung  : Stellt die Spaltenbreite eines ListView-Controls automatisch auf die optimale Breite ein.
'
'
' nderungen    :
' 18.03.05/Beju : Im Internet gefunden
'


' *********************************************************************
' *
' *    Modul mod_lvwResize
' *
' *    Stellt die Spaltenbreite eines ListView-Controls automatisch
' *    auf die optimale Breite ein. Es stehen folgende Funktionen
' *    zur Verfgung:
' *
' *       lvwSetSingleColWidth  -> stellt eine einzelne Spalte ein
' *       lvwSetMultiColWidth   -> stellt eine Liste von Spalten ein
' *       lvwSetAllColWidth     -> stellt alle Spalten auf einmal ein
' *
' *    Optional kann festgelegt werden, ob der Spalten-Header
' *    bercksichtigt werden soll:
' *
' *       lvw_AUTOSIZE             -> Header nicht bercksichtigen
' *       lvw_AUTOSIZE_WITH_HEADER -> Header bercksichtigen(Default)
' *
' *    April 2003 - Roland Wutzke
' *
' *********************************************************************

Option Explicit

' bentigte API
Private Declare Function SendMessage Lib "user32" Alias "SendMessageA" ( _
  ByVal hWnd As Long, _
  ByVal wMsg As Long, _
  ByVal wParam As Long, _
  lParam As Any) As Long

' bentigte Konstanten
Private Const LVM_FIRST As Long = &H1000
Private Const LVM_SETCOLUMNWIDTH As Long = LVM_FIRST + 30

' bentigte Aufzhlung
Public Enum lvw_Styles
  lvw_AUTOSIZE = -1
  lvw_AUTOSIZE_WITH_HEADER = -2
End Enum
Public Sub lvwSetAllColWidth(oListView As ListView, _
  Optional ByVal Style As lvw_Styles = lvw_AUTOSIZE_WITH_HEADER)

  Dim ColumnIndex As Long

  With oListView
    ' Schleife ber die Anzahl von Spalten im Listview
    For ColumnIndex = 1 To .ColumnHeaders.count
      ' Spalte bergeben und Breite einstellen
      lvwSetSingleColWidth oListView, _
        ColumnIndex, Style
    Next ColumnIndex
  End With
End Sub
Public Sub lvwSetMultiColWidth(oListView As ListView, _
  ByVal ColumnArray As Variant, _
  Optional ByVal Style As lvw_Styles = lvw_AUTOSIZE_WITH_HEADER)

  Dim ColumnIndex As Long

  ' Prfen, ob das bergebene Array ein Array ist
  If IsArray(ColumnArray) Then
    With oListView
      ' Schleife ber die gesamte Lnge des Arrays
      For ColumnIndex = LBound(ColumnArray) To UBound(ColumnArray)
        ' Prfen, ob das Array(Index) gltig ist
        If ColumnArray(ColumnIndex) <= .ColumnHeaders.count Then
          ' Spalte aus dem Array bergeben und Breite einstellen
          lvwSetSingleColWidth oListView, _
            ColumnArray(ColumnIndex), Style
        End If
      Next ColumnIndex
    End With
  End If
End Sub
Public Sub lvwSetSingleColWidth(oListView As ListView, ByVal ColumnIndex As Long, _
  Optional ByVal Style As lvw_Styles = lvw_AUTOSIZE_WITH_HEADER)

  With oListView
    ' Prfen, ob das Listview in der Ansicht "Report" ist
    If .View = lvwReport Then
      ' Prfen, ob der bergebene Spaltenindex zulssig ist
      If ColumnIndex >= 1 And ColumnIndex <= .ColumnHeaders.count Then
        ' API Aufruf an das Listview und Spalte einstellen
        Call SendMessage(.hWnd, LVM_SETCOLUMNWIDTH, _
          ColumnIndex - 1, ByVal Style)
      End If
    End If
  End With
End Sub



'''###################################################
'''###################################################
''
''Beispiel: (Sie bentigen eine Form mit einem ListView Control)
''
''' Alle Spalten sollen eingestellt werden. Dabei soll
''' auch der Column-Header bercksichtigt werden.
''lvwSetAllColWidth ListView1
''' Alle Spalten einstellen und den Header
''' nicht bercksichtigen
''lvwSetAllColWidth ListView1, lvw_AUTOSIZE
''' Nur bestimmte Spalten sollen eingestellt werden.
''' Die Liste wird mit einem Array abgebildet. In diesem Fall
''' werden die Spalten 1,3,4 und 6 bergeben.
''Dim colArray As Variant
''
''colArray = Array(1, 3, 4, 6)
''lvwSetMultiColWidth ListView1, colArray
''' Nur eine einzelne Spalte wird eingestellt.
''lvwSetSingleColWidth ListView1, 1
''
'''###################################################
'''###################################################
